@@ -610,6 +610,16 @@
         <source>Deleting</source>
         <translation>Poistetaan</translation>
     </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Vaihda kuvake</translation>
+    </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Apply to subfolders?</source>
+        <translation>Käytä alikansiot?</translation>
+    </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
