@@ -610,6 +610,16 @@
         <source>Deleting</source>
         <translation>Suppression</translation>
     </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Changer d'icône</translation>
+    </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Apply to subfolders?</source>
+        <translation>Appliquer aux sous-dossiers?</translation>
+    </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
